# eric7.EricUtilities

Package containing utility modules and functions.

### Packages

crypto | Package implementing cryptography related functionality.

### Modules

EricCache | Module implementing classes used for caching objects.
EricMutexLocker | Module implementing a context manager locking and unlocking a mutex.
EricPasswordChecker | Module implementing a checker for password strength.
EricUtilities | Package containing utility modules and functions.